from __future__ import unicode_literals

from stats_collector import FRED_DB
from stats_collector.stats import Statistics
from stats_collector.stats.stat_registry import stat_registry

from ..groups import FRED_DAILY_GROUP


@stat_registry.register(FRED_DAILY_GROUP)
class DomainsByDNSSECAlg(Statistics):
    sql = '''
        SELECT
            da.handle,
            COUNT(DISTINCT d.id)
        FROM
            history hk
            JOIN keyset_history k ON (
               hk.id = k.historyid
               AND hk.valid_from < %(midnight)s
               AND (hk.valid_to >= %(midnight)s OR hk.valid_to IS NULL)
            )
            JOIN domain_history d ON (d.keyset = k.id)
            JOIN history hd ON (
               hd.id = d.historyid
               AND hd.valid_from < %(midnight)s
               AND (hd.valid_to >= %(midnight)s OR hd.valid_to IS NULL)
            )
            JOIN dnskey_history dk ON (dk.historyid = k.historyid)
            JOIN dnssec_algorithm da ON (da.id = dk.alg)
            JOIN zone z ON (z.id = d.zone AND z.fqdn = 'cz')
        GROUP BY da.handle
    '''
    name = 'dnssec_by_algorithms'
    stat_db = FRED_DB
