from __future__ import unicode_literals

from stats_collector import FRED_DB
from stats_collector.stats import Statistics
from stats_collector.stats.stat_registry import stat_registry

from ..groups import FRED_DAILY_GROUP


@stat_registry.register(FRED_DAILY_GROUP)
class DomainsByCountries(Statistics):
    sql = '''
        SELECT
            C.country,
            COUNT(*)
        FROM
            object_registry O
            JOIN domain_history D ON (D.id = O.id)
            JOIN zone Z ON (D.zone = Z.id)
            JOIN history H ON (H.id = D.historyid)
            JOIN contact_history C ON (C.id = D.registrant)
            JOIN history HC ON (
                 HC.id = C.historyid AND
                 HC.valid_from < %(midnight)s AND
                 (HC.valid_to IS NULL OR HC.valid_to >= %(midnight)s)
            )
        WHERE type = 3
            AND O.name NOT LIKE '%(monitoring_domain)s'
            AND H.valid_from < %(midnight)s AND (H.valid_to IS NULL OR H.valid_to >= %(midnight)s)
            AND Z.fqdn = 'cz'
        GROUP BY 1

    '''
    name = 'domains_by_countries'
    stat_db = FRED_DB
