from __future__ import unicode_literals

from stats_collector import LOG_DB
from stats_collector.stats import Statistics
from stats_collector.stats.stat_registry import stat_registry

from ..groups import MOJEID_MONTHLY_GROUP


@stat_registry.register(MOJEID_MONTHLY_GROUP)
class MojeidAttributeCount(Statistics):
    sql = '''
      SELECT
        rp_attribute.value, COUNT(DISTINCT rp_realm.value)
      FROM
        request r
        JOIN request_type rt ON rt.id = r.request_type_id
        JOIN result_code rc ON rc.id = r.result_code_id AND rc.service_id = r.service_id
        JOIN request_property_value rp_realm ON rp_realm.request_id = r.id
        JOIN request_property_value rp_attribute ON rp_attribute.request_id = r.id
      WHERE
        %(log_req_cond_mojeid)s
        %(log_req_cond_mojeid_request_attributes)s
        AND rp_realm.property_name_id IN (
          SELECT id FROM request_property_name WHERE name IN ('realm', 'entity_id', 'redirect_uri')
        )
        AND rp_attribute.property_name_id IN (
          SELECT id FROM request_property_name WHERE name IN ('sreg_returned', 'ax_returned',
                                                              'attr_returned', 'returned_attributes')
        )
        AND rt.name IN ('OpenIDRequest', 'SamlRequest', 'OpenIDConnectRequest')
        AND rc.name = 'Success'
      GROUP BY rp_attribute.value
    '''
    name = 'mojeid_attribute_count'
    stat_db = LOG_DB
