from __future__ import unicode_literals

import six

from stats_collector import LOG_DB
from stats_collector.stats import Statistics
from stats_collector.stats.stat_registry import stat_registry
from stats_collector.utils import truncate_provider

from ..groups import MOJEID_DAILY_GROUP

INVALID_REALM = 'INVALID_REALM'


@stat_registry.register(MOJEID_DAILY_GROUP)
class MojeidConsumerAttributeCount(Statistics):
    sql = '''
      SELECT
        rp_realm.value, rp_attribute.value, COUNT(*)
      FROM
        request r
        JOIN request_type rt ON rt.id = r.request_type_id
        JOIN result_code rc ON rc.id = r.result_code_id AND rc.service_id = r.service_id
        JOIN request_property_value rp_realm ON rp_realm.request_id = r.id
        JOIN request_property_value rp_attribute ON rp_attribute.request_id = r.id
      WHERE
        %(log_req_cond_mojeid)s
        %(log_req_cond_mojeid_request_attributes)s
        AND rp_realm.property_name_id IN (
          SELECT id FROM request_property_name WHERE name IN ('realm', 'entity_id', 'redirect_uri')
        )
        AND rp_attribute.property_name_id IN (
          SELECT id FROM request_property_name WHERE name IN ('sreg_returned', 'ax_returned',
                                                              'attr_returned', 'returned_attributes')
        )
        AND rt.name IN ('OpenIDRequest', 'SamlRequest', 'OpenIDConnectRequest')
        AND rc.name = 'Success'
      GROUP BY rp_attribute.value, rp_realm.value
    '''
    name = 'mojeid_consumer_attribute_count'
    stat_db = LOG_DB

    def _format_data(self, data):
        """Iterate through data and flatten providers to domain only."""
        if data:
            # First normalize providers to domain only
            for row in data:
                row[0] = truncate_provider(row[0])
            # Iterate through normalized data and group rows by the normalized URL.
            temp_data = {}
            for row in data:
                provider_attribute = (row[0], row[1])
                temp_data[provider_attribute] = temp_data.get(provider_attribute, 0) + row[2]
            new_data = [[k[0], k[1], v] for k, v in six.iteritems(temp_data)]
            return super(MojeidConsumerAttributeCount, self)._format_data(new_data)
