from __future__ import unicode_literals

import six

from stats_collector import LOG_DB
from stats_collector.stats import Statistics
from stats_collector.stats.stat_registry import stat_registry
from stats_collector.utils import truncate_provider

from ..groups import MOJEID_DAILY_GROUP


@stat_registry.register(MOJEID_DAILY_GROUP)
class MojeidConsumerLoginCount(Statistics):
    sql = '''
       SELECT
         rp.value, COUNT(*)
       FROM
         request r
         JOIN request_type rt ON rt.id = r.request_type_id
         JOIN result_code rc ON rc.id = r.result_code_id AND rc.service_id = r.service_id
         JOIN request_property_value rp ON rp.request_id = r.id
       WHERE
         %(log_req_cond_mojeid)s
         %(log_req_cond_mojeid_request_property_value)s
         AND rp.property_name_id IN (
            SELECT id FROM request_property_name WHERE name IN ('realm', 'entity_id', 'redirect_uri')
         )
         AND rt.name IN ('OpenIDRequest', 'SamlRequest', 'OpenIDConnectRequest')
         AND rc.name = 'Success'
       GROUP BY rp.value
    '''
    name = 'mojeid_consumer_login_count'
    stat_db = LOG_DB

    def _format_data(self, data):
        """Iterate through data and flatten providers to domain only."""
        if data:
            # First normalize providers to domain only
            for row in data:
                row[0] = truncate_provider(row[0])
            # Iterate through normalized data values and group rows by the normalized URL.
            temp_data = {}
            for row in data:
                provider = row[0]
                temp_data[provider] = temp_data.get(provider, 0) + row[1]
            new_data = [[k, v] for k, v in six.iteritems(temp_data)]
            return super(MojeidConsumerLoginCount, self)._format_data(new_data)
