from __future__ import unicode_literals

from stats_collector import LOG_DB
from stats_collector.stats import Statistics
from stats_collector.stats.stat_registry import stat_registry

from ..groups import MOJEID_DAILY_GROUP


@stat_registry.register(MOJEID_DAILY_GROUP)
class MojeidLoginMethodCount(Statistics):
    sql = '''
       SELECT
         rp.value, COUNT(*)
       FROM
         request r
         JOIN request_type rt ON rt.id = r.request_type_id
         JOIN result_code rc ON rc.id = r.result_code_id AND rc.service_id = r.service_id
         JOIN request_property_value rp ON rp.request_id = r.id
       WHERE
         %(log_req_cond_mojeid)s
         %(log_req_cond_mojeid_request_property_value)s
         AND rp.value in ('password', 'otp', 'certificate')
         AND rp.property_name_id IN (SELECT id FROM request_property_name WHERE name = 'method')
         AND rt.name = 'Login'
         AND rc.name = 'Success'
       GROUP BY rp.value
    '''
    name = 'mojeid_login_method_count'
    stat_db = LOG_DB
