"""Unittests for utils."""
from __future__ import unicode_literals

from unittest import TestCase

from stats_collector.utils import INVALID_REALM, time_measure, truncate_provider


class TestTimeMeasure(TestCase):
    """Tests for ``time_measure`` function."""

    def test_func(self):
        def some_func():
            pass

        time_measure(some_func)

    def test_other_func(self):
        class SomeTestClass():
            def some_func(self):
                pass

        test = SomeTestClass()
        time_measure(test.some_func)


class TestTruncateProvider(TestCase):
    """Tests for ``truncate_provider`` function."""

    def test_invalid_url(self):
        self.assertEqual(truncate_provider(''), INVALID_REALM)
        self.assertEqual(truncate_provider('test'), INVALID_REALM)
        self.assertEqual(truncate_provider('example.com/'), INVALID_REALM)
        self.assertEqual(truncate_provider('http://example'), INVALID_REALM)

    def test_shorten(self):
        self.assertEqual(truncate_provider('https://example.com/path/'), 'https://example.com')
        self.assertEqual(truncate_provider('https://example.com/?query=some/'), 'https://example.com')

    def test_long_provider(self):
        self.assertEqual(truncate_provider('https://' + 'a' * 254 + '.com'), INVALID_REALM)
