from __future__ import unicode_literals

import time
import types

from furl import furl

from stats_collector import config

log_file = open(config.LOG_FILE, 'a')
INVALID_REALM = 'INVALID_REALM'


def time_measure(func, *args, **kwd):
    """Call and measures time of inner function/method.

    Write result to log file and if DEBUG is True that to stdout, too.
    """
    if isinstance(func, types.FunctionType):
        f_name = func.__name__
    else:
        f_name = '%s.%s' % (func.__self__.__class__.__name__, func.__func__.__name__)

    if config.DEBUG:
        print(f_name)

    t1 = time.time()
    result = func(*args, **kwd)
    t_diff = time.time() - t1

    log_file.write('%-40s %10.3f\n' % (f_name + ':', t_diff))
    if config.DEBUG:
        print('%-40s %10.3f' % (f_name + ':', t_diff))

    return result


def truncate_provider(provider):
    """Truncate provider to domain part only."""
    try:
        # This can raise uncaught exception if the label is too long
        provider = furl(provider)
        netloc = provider.netloc
    except UnicodeError:
        return INVALID_REALM

    if provider.scheme is None or netloc == '':
        return INVALID_REALM
    elif '.' not in provider.origin:
        return INVALID_REALM
    else:
        return provider.origin
